==> RPESE_1.0.2.tar.gz: RPESE/R/EstimatorSE_utils.R <==
# Compute the standard error for the xts object
SE.xts = function(x, se.fun, myfun, myfun.IF,
                  prewhiten=FALSE, cleanOutliers=FALSE, fitting.method=c("Exponential", "Gamma")[1],
                  freq.include=c("All", "Decimate", "Truncate")[1], freq.par=0.5, d.GLM.EN = 5,
                  ...){
  if (is.vector(x) || is.null(ncol(x)) || ncol(x) == 1) {
    x <- as.numeric(x)
    #    if(na.rm) x <- na.omit(x)
    return(se.fun(x = x, myfun = myfun, myfun.IF = myfun.IF,
                  prewhiten=prewhiten, cleanOutliers=cleanOutliers, fitting.method=fitting.method,
                  freq.include=freq.include, freq.par=freq.par, d.GLM.EN = d.GLM.EN,
                  ...))
  }
  else {
    x <- coredata(x)
    #    if(na.rm) x <- na.omit(x)
    return(apply(x, 2, se.fun, myfun = myfun, myfun.IF = myfun.IF,
                 prewhiten=prewhiten, cleanOutliers=cleanOutliers, fitting.method=fitting.method,
                 freq.include=freq.include, freq.par=freq.par, d.GLM.EN = d.GLM.EN,
                 ...))
  }
}

# Compute the standard error using influence function approach for a vector
SE.IF.iid = function(x, myfun.IF, ...){
  N=length(x)
  x.IF = myfun.IF(x, ...)
  x.IF.2 = x.IF^2
  tmp = mean(x.IF.2)
  return(sqrt(tmp/N))
}

# Compute the standard error of the measure by iid bootstrapping
SE.BOOT.iid = function(x, myfun, myfun.IF, prewhiten=FALSE, ..., nsim = 100){
  res = boot(data = x, statistic = function(x,i,...) myfun(x[i],...), R = nsim, ... = ...)
  return(sd(res$t))
}

# Compute the standard error of the measure by tsboot()
SE.BOOT.cor = function(x, myfun, myfun.IF, prewhiten=FALSE, ..., nsim = 1000,
                       sim = "fixed", l = round(length(x)/5)){
  res = tsboot(tseries = x, statistic = function(x,...) myfun(x,...), R = nsim,
               sim = sim, l = l,...)
  return(sd(res$t))
}

# Compute the standard error using GLM-EN approach for serially correlated data using RPEGLMEN
SE.IF.cor = function(x, myfun.IF,
                     d.GLM.EN = 5, alpha.EN = 0.5, keep = 1,
                     standardize = FALSE,
                     prewhiten=FALSE, cleanOutliers=FALSE, fitting.method=c("Exponential", "Gamma")[1],
                     freq.include=c("All", "Decimate", "Truncate")[1], freq.par=0.5,
                     return.coef=FALSE,
                     ...){
  data.IF = myfun.IF(x, prewhiten=prewhiten, cleanOutliers=cleanOutliers, ...)
  if(prewhiten){
    ar.coeffs <- as.numeric(arima(x=x, order=c(1,0,0), include.mean=TRUE)$coef[1])
  } else{
    ar.coeffs <- NULL
  }
  tmp = SE.glmnet_exp(data.IF, standardize = standardize,
                      d = d.GLM.EN, alpha.EN = alpha.EN, keep = keep,
                      fitting.method = fitting.method,
                      freq.include = freq.include, freq.par = freq.par,
                      prewhiten = prewhiten, ar.coeffs = ar.coeffs,
                      return.coef = return.coef,
                      ...)
  if(return.coef){
    coeffs = tmp[[2]]
    tmp = tmp[[1]]
    return(list(se=sqrt(tmp), coef=coeffs))
  }
  return(sqrt(tmp))
}

==> RPESE_1.0.4.tar.gz: RPESE/R/EstimatorSE_utils.R <==
# Compute the standard error for the xts object
SE.xts = function(x, se.fun, myfun, myfun.IF,
                  prewhiten=FALSE, cleanOutliers=FALSE, fitting.method=c("Exponential", "Gamma")[1],
                  freq.include=c("All", "Decimate", "Truncate")[1], freq.par=0.5, d.GLM.EN = 5,
                  ...){
  if (is.vector(x) || is.null(ncol(x)) || ncol(x) == 1) {
    x <- as.numeric(x)
    #    if(na.rm) x <- na.omit(x)
    return(se.fun(x = x, myfun = myfun, myfun.IF = myfun.IF,
                  prewhiten=prewhiten, cleanOutliers=cleanOutliers, fitting.method=fitting.method,
                  freq.include=freq.include, freq.par=freq.par, d.GLM.EN = d.GLM.EN,
                  ...))
  }
  else {
    x <- coredata(x)
    #    if(na.rm) x <- na.omit(x)
    return(apply(x, 2, se.fun, myfun = myfun, myfun.IF = myfun.IF,
                 prewhiten=prewhiten, cleanOutliers=cleanOutliers, fitting.method=fitting.method,
                 freq.include=freq.include, freq.par=freq.par, d.GLM.EN = d.GLM.EN,
                 ...))
  }
}

# Compute the standard error using influence function approach for a vector
SE.IF.iid = function(x, myfun.IF, ...){
  N=length(x)
  x.IF = myfun.IF(x, ...)
  x.IF.2 = x.IF^2
  tmp = mean(x.IF.2)
  return(sqrt(tmp/N))
}

# Compute the standard error of the measure by iid bootstrapping
SE.BOOT.iid = function(x, myfun, myfun.IF, prewhiten=FALSE, ..., nsim = 100){
  res = boot(data = x, statistic = function(x,i,...) myfun(x[i],...), R = nsim, ... = ...)
  return(sd(res$t))
}

# Compute the standard error of the measure by tsboot()
SE.BOOT.cor = function(x, myfun, myfun.IF, prewhiten=FALSE, ..., nsim = 1000,
                       sim = "fixed", l = round(length(x)/5)){
  res = tsboot(tseries = x, statistic = function(x,...) myfun(x,...), R = nsim,
               sim = sim, l = l,...)
  return(sd(res$t))
}

# Compute the standard error using GLM-EN approach for serially correlated data using RPEGLMEN
SE.IF.cor = function(x, myfun.IF,
                     d.GLM.EN = 5, alpha.EN = 0.5, keep = 1,
                     standardize = FALSE,
                     prewhiten=FALSE, cleanOutliers=FALSE, fitting.method=c("Exponential", "Gamma")[1],
                     freq.include=c("All", "Decimate", "Truncate")[1], freq.par=0.5,
                     return.coef=FALSE,
                     ...){
  data.IF = myfun.IF(x, prewhiten=prewhiten, cleanOutliers=cleanOutliers, ...)
  if(prewhiten){
    ar.coeffs <- as.numeric(arima(x=data.IF, order=c(1,0,0), include.mean=TRUE)$coef[1])
  } else{
    ar.coeffs <- NULL
  }
  tmp = SE.glmnet_exp(data.IF, standardize = standardize,
                      d = d.GLM.EN, alpha.EN = alpha.EN, keep = keep,
                      fitting.method = fitting.method,
                      freq.include = freq.include, freq.par = freq.par,
                      prewhiten = prewhiten, ar.coeffs = ar.coeffs,
                      return.coef = return.coef,
                      ...)
  if(return.coef){
    coeffs = tmp[[2]]
    tmp = tmp[[1]]
    return(list(se=sqrt(tmp), coef=coeffs))
  }
  return(sqrt(tmp))
}
